@@ -188,6 +188,7 @@ EXTENSIONS = {
     'woff': {'binary', 'woff'},
     'woff2': {'binary', 'woff2'},
     'wsgi': {'text', 'wsgi', 'python'},
+    'xhtml': {'text', 'xml', 'xhtml'},
     'xml': {'text', 'xml'},
     'xq': {'text', 'xquery'},
     'xql': {'text', 'xquery'},
@@ -219,6 +220,7 @@ NAMES = {
     '.cshrc': EXTENSIONS['csh'],
     '.dockerignore': {'text', 'dockerignore'},
     '.editorconfig': {'text', 'editorconfig'},
+    '.flake8': EXTENSIONS['ini'] | {'flake8'},
     '.gitconfig': EXTENSIONS['ini'] | {'gitconfig'},
     '.hgrc': EXTENSIONS['ini'] | {'hgrc'},
     '.gitattributes': {'text', 'gitattributes'},
@@ -230,6 +232,7 @@ NAMES = {
     '.npmignore': {'text', 'npmignore'},
     '.pdbrc': EXTENSIONS['py'] | {'pdbrc'},
     '.pypirc': EXTENSIONS['ini'] | {'pypirc'},
+    '.rstcheck.cfg': EXTENSIONS['ini'],
     '.yamllint': EXTENSIONS['yaml'] | {'yamllint'},
     '.zshrc': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
